@@ -1,4 +1,4 @@
-%% Copyright (c) 2015, Loïc Hoguin <essen@ninenines.eu>
+%% Copyright (c) 2015-2016, Loïc Hoguin <essen@ninenines.eu>
 %%
 %% Permission to use, copy, modify, and/or distribute this software for any
 %% purpose with or without fee is hereby granted, provided that the above
@@ -17,7 +17,7 @@
 -export([init/2]).
 
 init(_, _) ->
-	ct_helper:start([ranch, ssl]),
+	ct_helper:start([ranch]),
 	ct_helper:make_certs_in_ets(),
 	error_logger:add_report_handler(ct_helper_error_h),
 	{ok, undefined}.
